==> fred_ferda_verification-1.6.0rc4.tar.gz: fred_ferda_verification-1.6.0rc4/assets/js/main.js <==
import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { get_vuetify_options, i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import VerificationBaseView from './components/VerificationBaseView.vue'
import ContactVerification from './components/contact/ContactVerification.vue'
import DomainOwnerVerification from './components/domain/DomainOwnerVerification.vue'
import AccountCheck from './components/icons/AccountCheck.vue'
import AccountXmark from './components/icons/AccountXmark.vue'
import { get_ferda_verification_i18next_options, get_verification_settings, store } from './main.config'
import router from './router'
import { wait_for_element } from './utils'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

document.addEventListener('ferda-loaded', async({ detail }) => {
    await i18next.use(Backend).init(get_ferda_verification_i18next_options(detail.settings.django_settings.version))
    store.commit(
        'verification_settings/set_verification_portal_url',
        detail.settings.django_settings.verification.verification_portal_url,
    )

    if (destination) {
        const verification_settings = await get_verification_settings()
        if (verification_settings === null) {
            return
        }
        store.commit('verification_settings/set_verification_settings', verification_settings.VERIFICATION_REASONS)
    }

    const options = get_vuetify_options()
    options.theme.themes.dark = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.theme.themes.light = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.icons = {
        ...options.icons,
        values: {
            ...(options.icons && options.icons.values),
            account_check: {
                component: AccountCheck,
            },
            account_xmark: {
                component: AccountXmark,
            },
        },
    }

    const permissions = store.getters['general/permissions']
    if (destination === 'verification-module') {
        const verificationEl = document.querySelector('#verification')
        if (verificationEl) {
            new Vue({
                el: '#verification',
                name: 'VerificationIndex',
                vuetify: new Vuetify(options),
                i18n,
                components: { VerificationBaseView },
                store,
                router,
                render: createElement => createElement(VerificationBaseView),
            })
        }
    }

    if (destination === 'contact-detail' && permissions.includes('ferda_verification.can_view')) {
        const ferda_verification_section_el = document.createElement('div')
        ferda_verification_section_el.id = 'verification-section'

        document.querySelector('.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div > div')
            .appendChild(ferda_verification_section_el)

        const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)

        new Vue({
            el: '#verification-section',
            name: 'VerificationPlugin',
            vuetify: new Vuetify(options),
            i18n,
            components: { ContactVerification },
            store,
            render: createElement => createElement(ContactVerification, { props: { contact: contact_data }}),
        })
    }

    if (destination === 'domain-detail' && permissions.includes('ferda_verification.can_view')) {
        // Title section logic
        const original_title_el = await wait_for_element(
            `.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div >
            div > div:nth-child(2) > div > div > div > div > div > div`,
        )
        const original_title = original_title_el.innerText

        const new_title_el = document.createElement('div')
        new_title_el.id = 'verification-title-el'
        original_title_el.replaceWith(new_title_el)

        const registrant_id = JSON.parse(document.querySelector('#domain-data').textContent).object_info.registrant
        new Vue({
            el: '#verification-title-el',
            name: 'VerificationOwnerTitle',
            vuetify: new Vuetify(options),
            i18n,
            components: { DomainOwnerVerification },
            render: createElement => createElement(DomainOwnerVerification, {
                props: { registrant_id, original_title },
            }),
        })
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }

==> fred_ferda_verification-1.9.0rc2.tar.gz: fred_ferda_verification-1.9.0rc2/assets/js/main.js <==
import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import {
    get_ferda_verification_i18next_options,
    get_verification_settings,
    get_verification_vuetify_options,
    store,
} from 'ferda_verification_js/main.config'

import VerificationBaseView from './components/VerificationBaseView.vue'
import ContactVerification from './components/contact/ContactVerification.vue'
import DomainOwnerVerification from './components/domain/DomainOwnerVerification.vue'
import AccountCheck from './components/icons/AccountCheck.vue'
import AccountXmark from './components/icons/AccountXmark.vue'
import router from './router'
import { wait_for_element } from './utils'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

document.addEventListener('ferda-loaded', async({ detail }) => {
    await i18next.use(Backend).init(get_ferda_verification_i18next_options(detail.settings.django_settings.version))
    store.commit(
        'verification_settings/set_verification_portal_url',
        detail.settings.django_settings.verification.verification_portal_url,
    )

    if (destination) {
        const verification_settings = await get_verification_settings()
        if (verification_settings === null) {
            return
        }
        store.commit('verification_settings/set_verification_settings', verification_settings.VERIFICATION_REASONS)
    }
    const options = get_verification_vuetify_options()
    options.theme.themes.dark = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.theme.themes.light = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.icons = {
        ...options.icons,
        values: {
            ...(options.icons && options.icons.values),
            account_check: {
                component: AccountCheck,
            },
            account_xmark: {
                component: AccountXmark,
            },
        },
    }

    const permissions = store.getters['general/permissions']
    if (destination === 'verification-module') {
        const verificationEl = document.querySelector('#verification')
        if (verificationEl) {
            new Vue({
                el: '#verification',
                name: 'VerificationIndex',
                vuetify: new Vuetify(options),
                i18n,
                components: { VerificationBaseView },
                store,
                router,
                render: createElement => createElement(VerificationBaseView),
            })
        }
    }

    if (destination === 'contact-detail' && permissions.includes('ferda_verification.can_view')) {
        const ferda_verification_section_el = document.createElement('div')
        ferda_verification_section_el.id = 'verification-section'

        document.querySelector('.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div > div')
            .appendChild(ferda_verification_section_el)

        const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)

        new Vue({
            el: '#verification-section',
            name: 'VerificationPlugin',
            vuetify: new Vuetify(options),
            i18n,
            components: { ContactVerification },
            store,
            render: createElement => createElement(ContactVerification, { props: { contact: contact_data }}),
        })
    }

    if (destination === 'domain-detail' && permissions.includes('ferda_verification.can_view')) {
        // Title section logic
        const original_title_el = await wait_for_element(
            `.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div >
            div > div:nth-child(2) > div > div > div > div > div > div`,
        )
        const original_title = original_title_el.innerText

        const new_title_el = document.createElement('div')
        new_title_el.id = 'verification-title-el'
        original_title_el.replaceWith(new_title_el)

        const registrant_id = JSON.parse(document.querySelector('#domain-data').textContent).object_info.registrant
        new Vue({
            el: '#verification-title-el',
            name: 'VerificationOwnerTitle',
            vuetify: new Vuetify(options),
            i18n,
            components: { DomainOwnerVerification },
            render: createElement => createElement(DomainOwnerVerification, {
                props: { registrant_id, original_title },
            }),
        })
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }
